/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * MAVEfast_terminate.cpp
 *
 * Code generation for function 'MAVEfast_terminate'
 *
 */

/* Include files */
#include "rt_nonfinite.h"
#include "MAVEfast.h"
#include "MAVEfast_terminate.h"

/* Function Definitions */
void MAVEfast_terminate()
{
  /* (no terminate code required) */
}

/* End of code generation (MAVEfast_terminate.cpp) */
